@@ -112,11 +112,11 @@ typedef void (*uat_reset_cb_t)(void);
  * fields had been updated (either from file or after modifications in the GUI).
  *
  * Optional, the record will be considered valid if the callback is omitted.
- * It must return TRUE if the contents are considered valid and FALSE otherwise
+ * It must return true if the contents are considered valid and false otherwise
  * in which case the failure reason is set in 'error'. The error string will be
  * freed by g_free.
  */
-typedef gboolean (*uat_update_cb_t)(void *record, char **error);
+typedef bool (*uat_update_cb_t)(void *record, char **error);
 
 
 /*******
@@ -129,14 +129,14 @@ typedef gboolean (*uat_update_cb_t)(void *record, char **error);
  * chk(record, ptr, len, chk_data, fld_data, &error)
  *
  * given an input string (ptr, len) checks if the value is OK for a field in the record.
- * it will return TRUE if OK or else
- * it will return FALSE and set *error to inform the user on what's
+ * it will return true if OK or else
+ * it will return false and set *error to inform the user on what's
  * wrong with the given input
  * The error string must be allocated with g_malloc() or
  * a routine that calls it.
  * optional, if not given any input is considered OK and the set cb will be called
  */
-typedef gboolean (*uat_fld_chk_cb_t)(void *record, const char *ptr, unsigned len, const void *chk_data, const void *fld_data, char **error);
+typedef bool (*uat_fld_chk_cb_t)(void *record, const char *ptr, unsigned len, const void *chk_data, const void *fld_data, char **error);
 
 /*
  * Set Field CB
@@ -268,7 +268,7 @@ typedef struct _uat_field_t {
  * @param name The name of the table
  * @param size The size of the structure
  * @param filename The filename to be used (either in userdir or datadir)
- * @param from_profile TRUE if profile directory to be used
+ * @param from_profile true if profile directory to be used
  * @param data_ptr Although a void*, this is really a pointer to a null terminated array of pointers to the data
  * @param num_items_ptr A pointer with number of items
  * @param flags flags indicating what this UAT affects
@@ -286,10 +286,10 @@ WS_DLL_PUBLIC
 uat_t* uat_new(const char* name,
 			   size_t size,
 			   const char* filename,
-			   gboolean from_profile,
+			   bool from_profile,
 			   void* data_ptr,
-			   guint* num_items_ptr,
-			   guint flags,
+			   unsigned* num_items_ptr,
+			   unsigned flags,
 			   const char* help,
 			   uat_copy_cb_t copy_cb,
 			   uat_update_cb_t update_cb,
@@ -309,10 +309,10 @@ void uat_cleanup(void);
  * @param filename Filename to load, NULL to fetch from current profile.
  * @param err Upon failure, points to an error string.
  *
- * @return TRUE on success, FALSE on failure.
+ * @return true on success, false on failure.
  */
 WS_DLL_PUBLIC
-gboolean uat_load(uat_t* uat_in, const gchar *filename, char** err);
+bool uat_load(uat_t* uat_in, const char *filename, char** err);
 
 /** Create or update a single UAT entry using a string.
  *
@@ -321,9 +321,9 @@ gboolean uat_load(uat_t* uat_in, const gchar *filename, char** err);
  * what's written to the uat's output file.
  * @param err Upon failure, points to an error string.
  *
- * @return TRUE on success, FALSE on failure.
+ * @return true on success, false on failure.
  */
-gboolean uat_load_str(uat_t* uat_in, char* entry, char** err);
+bool uat_load_str(uat_t* uat_in, char* entry, char** err);
 
 /** Given a UAT name or filename, find its pointer.
  *
@@ -331,7 +331,7 @@ gboolean uat_load_str(uat_t* uat_in, char* entry, char** err);
  *
  * @return A pointer to the uat on success, NULL on failure.
  */
-uat_t *uat_find(gchar *name);
+uat_t *uat_find(char *name);
 
 WS_DLL_PUBLIC
 uat_t* uat_get_table_by_name(const char* name);
@@ -356,57 +356,57 @@ void uat_set_default_values(uat_t *uat_in, const char *default_values[]);
  * Some common uat_fld_chk_cbs
  */
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_str(void*, const char*, unsigned, const void*, const void*, char** err);
-gboolean uat_fld_chk_oid(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_str(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_oid(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_proto(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_proto(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_num_dec(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_num_dec(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_num_dec64(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_num_dec64(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_num_hex(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_num_hex(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_num_hex64(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_num_hex64(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_num_signed_dec(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_num_signed_dec(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_num_signed_dec64(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_num_signed_dec64(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_bool(void*, const char*, unsigned, const void*, const void*, char** err);
+bool uat_fld_chk_bool(void*, const char*, unsigned, const void*, const void*, char** err);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_enum(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_enum(void*, const char*, unsigned, const void*, const void*, char**);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_range(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_range(void*, const char*, unsigned, const void*, const void*, char**);
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_color(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_color(void*, const char*, unsigned, const void*, const void*, char**);
 
 typedef void (*uat_cb_t)(void* uat,void* user_data);
 WS_DLL_PUBLIC
 void uat_foreach_table(uat_cb_t cb,void* user_data);
 void uat_unload_all(void);
 
-char* uat_undquote(const char* si, guint in_len, guint* len_p);
-char* uat_unbinstring(const char* si, guint in_len, guint* len_p);
-char* uat_unesc(const char* si, guint in_len, guint* len_p);
-char* uat_esc(const char* buf, guint len);
+char* uat_undquote(const char* si, unsigned in_len, unsigned* len_p);
+char* uat_unbinstring(const char* si, unsigned in_len, unsigned* len_p);
+char* uat_unesc(const char* si, unsigned in_len, unsigned* len_p);
+char* uat_esc(const char* buf, unsigned len);
 
 /* Some strings entirely made of ... already declared */
 
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_str_isprint(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_str_isprint(void*, const char*, unsigned, const void*, const void*, char**);
 
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_str_isalpha(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_str_isalpha(void*, const char*, unsigned, const void*, const void*, char**);
 
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_str_isalnum(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_str_isalnum(void*, const char*, unsigned, const void*, const void*, char**);
 
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_str_isdigit(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_str_isdigit(void*, const char*, unsigned, const void*, const void*, char**);
 
 WS_DLL_PUBLIC
-gboolean uat_fld_chk_str_isxdigit(void*, const char*, unsigned, const void*, const void*, char**);
+bool uat_fld_chk_str_isxdigit(void*, const char*, unsigned, const void*, const void*, char**);
 
 
 /*
@@ -426,7 +426,7 @@ gboolean uat_fld_chk_str_isxdigit(void*, const char*, unsigned, const void*, con
  *    a simple c-string contained in (((rec_t*)rec)->(field_name))
  */
 #define UAT_CSTRING_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
     char* new_buf = g_strndup(buf,len); \
 	g_free((((rec_t*)rec)->field_name)); \
 	(((rec_t*)rec)->field_name) = new_buf; } \
@@ -499,7 +499,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  * LSTRING MACROS
  */
 #define UAT_LSTRING_CB_DEF(basename,field_name,rec_t,ptr_element,len_element) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* new_val = uat_unesc(buf,len,&(((rec_t*)rec)->len_element)); \
         g_free((((rec_t*)rec)->ptr_element)); \
 	(((rec_t*)rec)->ptr_element) = new_val; }\
@@ -523,7 +523,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *    and its len in (((rec_t*)rec)->(len_name))
  */
 #define UAT_BUFFER_CB_DEF(basename,field_name,rec_t,ptr_element,len_element) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	unsigned char* new_buf = len ? (unsigned char *)g_memdup2(buf,len) : NULL; \
 	g_free((((rec_t*)rec)->ptr_element)); \
 	(((rec_t*)rec)->ptr_element) = new_buf; \
@@ -541,7 +541,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *   an unsigned decimal number contained in (((rec_t*)rec)->(field_name))
  */
 #define UAT_DEC_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	ws_strtou32(tmp_str, NULL, &((rec_t*)rec)->field_name); \
 	g_free(tmp_str); } \
@@ -556,7 +556,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
   *   an unsigned 64bit decimal number contained in (((rec_t*)rec)->(field_name))
   */
 #define UAT_DEC64_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	ws_strtou64(tmp_str, NULL, &((rec_t*)rec)->field_name); \
 	g_free(tmp_str); } \
@@ -571,7 +571,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *   a *signed* decimal number contained in (((rec_t*)rec)->(field_name))
  */
 #define UAT_SIGNED_DEC_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	ws_strtoi32(tmp_str, NULL, &((rec_t*)rec)->field_name); \
 	g_free(tmp_str); } \
@@ -586,7 +586,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
   *   and a *signed* 64bit decimal number contained in (((rec_t*)rec)->(field_name))
   */
 #define UAT_SIGNED_DEC64_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	ws_strtoi64(tmp_str, NULL, &((rec_t*)rec)->field_name); \
 	g_free(tmp_str); } \
@@ -606,7 +606,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *   an unsigned hexadecimal number contained in (((rec_t*)rec)->(field_name))
  */
 #define UAT_HEX_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	ws_hexstrtou32(tmp_str, NULL, &((rec_t*)rec)->field_name); \
 	g_free(tmp_str); } \
@@ -622,7 +622,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
   *   an unsigned long long hexadecimal number contained in (((rec_t*)rec)->(field_name))
   */
 #define UAT_HEX64_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	ws_hexstrtou64(tmp_str, NULL, &((rec_t*)rec)->field_name); \
 	g_free(tmp_str); } \
@@ -638,7 +638,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *   an boolean value contained in (((rec_t*)rec)->(field_name))
  */
 #define UAT_BOOL_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	char* tmp_str = g_strndup(buf,len); \
 	if (g_strcmp0(tmp_str, "TRUE") == 0) \
 		((rec_t*)rec)->field_name = 1; \
@@ -660,8 +660,8 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *        value
  */
 #define UAT_VS_DEF(basename,field_name,rec_t,default_t,default_val,default_str) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* vs, const void* UNUSED_PARAMETER(u2)) {\
-	guint i; \
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* vs, const void* UNUSED_PARAMETER(u2)) {\
+	unsigned i; \
 	char* str = g_strndup(buf,len); \
 	const char* cstr; \
 	((rec_t*)rec)->field_name = default_val; \
@@ -674,7 +674,7 @@ static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, g
 	} \
 	g_free(str); } \
 static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr, unsigned* out_len, const void* vs, const void* UNUSED_PARAMETER(u2)) {\
-	guint i; \
+	unsigned i; \
 	for(i=0;((const value_string*)vs)[i].strptr;i++) { \
 		if ( ((const value_string*)vs)[i].value == ((rec_t*)rec)->field_name ) { \
 			*out_ptr = g_strdup(((const value_string*)vs)[i].strptr); \
@@ -686,8 +686,8 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
 	*out_len = (unsigned)strlen(default_str); }
 
 #define UAT_VS_CSTRING_DEF(basename,field_name,rec_t,default_val,default_str) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* vs, const void* UNUSED_PARAMETER(u2)) {\
-	guint i; \
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* vs, const void* UNUSED_PARAMETER(u2)) {\
+	unsigned i; \
 	char* str = g_strndup(buf,len); \
 	const char* cstr; \
 	((rec_t*)rec)->field_name = default_val; \
@@ -715,13 +715,13 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  *   an #RRGGBB color value contained in (((rec_t*)rec)->(field_name))
  */
 #define UAT_COLOR_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	if (len < 1) { \
 		((rec_t*)rec)->field_name = 0; \
 		return; \
 	} \
 	char* tmp_str = g_strndup(buf+1,len-1); \
-	((rec_t*)rec)->field_name = (guint)strtol(tmp_str,NULL,16); \
+	((rec_t*)rec)->field_name = (unsigned)strtol(tmp_str,NULL,16); \
 	g_free(tmp_str); } \
 static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr, unsigned* out_len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	*out_ptr = ws_strdup_printf("#%06X",((rec_t*)rec)->field_name); \
@@ -736,7 +736,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  */
 
 #define UAT_DISSECTOR_DEF(basename, field_name, dissector_field, name_field, rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* UNUSED_PARAMETER(u2)) {\
 	if (len) { \
 		((rec_t*)rec)->name_field = g_strndup(buf, len); \
 		g_strstrip(((rec_t*)rec)->name_field); \
@@ -761,7 +761,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, char** out_ptr,
  */
 
 #define UAT_RANGE_CB_DEF(basename,field_name,rec_t) \
-static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, guint len, const void* UNUSED_PARAMETER(u1), const void* u2) {\
+static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, const void* UNUSED_PARAMETER(u1), const void* u2) {\
 	char* rng = g_strndup(buf,len);\
 		range_convert_str(NULL, &(((rec_t*)rec)->field_name), rng,GPOINTER_TO_UINT(u2)); \
 		g_free(rng); \
