@@ -10,14 +10,15 @@
  */
 
 #include <config.h>
+#define WS_LOG_DOMAIN "randpkt"
 
 #include "randpkt_core.h"
 
 #include <time.h>
-#include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 #include <wsutil/file_util.h>
+#include <wsutil/wslog.h>
 #include <wiretap/wtap_opttypes.h>
 
 #include "ui/failure_message.h"
@@ -620,16 +621,16 @@ void randpkt_loop(randpkt_example* example, guint64 produce_count, guint64 packe
 		}
 
 		if (!wtap_dump(example->dump, rec, buffer, &err, &err_info)) {
-			cfile_write_failure_message("randpkt", NULL,
+			cfile_write_failure_message(NULL,
 			    example->filename, err, err_info, 0,
-			    WTAP_FILE_TYPE_SUBTYPE_PCAP);
+			    wtap_dump_file_type_subtype(example->dump));
 		}
 		if (packet_delay_ms) {
 			g_usleep(1000 * (gulong)packet_delay_ms);
 			if (!wtap_dump_flush(example->dump, &err)) {
-				cfile_write_failure_message("randpkt", NULL,
+				cfile_write_failure_message(NULL,
 				    example->filename, err, NULL, 0,
-				    WTAP_FILE_TYPE_SUBTYPE_PCAP);
+				    wtap_dump_file_type_subtype(example->dump));
 			}
 		}
 	}
@@ -644,7 +645,7 @@ gboolean randpkt_example_close(randpkt_example* example)
 	gchar *err_info;
 	gboolean ok = TRUE;
 
-	if (!wtap_dump_close(example->dump, &err, &err_info)) {
+	if (!wtap_dump_close(example->dump, NULL, &err, &err_info)) {
 		cfile_close_failure_message(example->filename, err, err_info);
 		ok = FALSE;
 	}
@@ -657,7 +658,7 @@ gboolean randpkt_example_close(randpkt_example* example)
 	return ok;
 }
 
-int randpkt_example_init(randpkt_example* example, char* produce_filename, int produce_max_bytes)
+int randpkt_example_init(randpkt_example* example, char* produce_filename, int produce_max_bytes, int file_type_subtype)
 {
 	int err;
 	gchar *err_info;
@@ -672,17 +673,17 @@ int randpkt_example_init(randpkt_example* example, char* produce_filename, int p
 	};
 	if (strcmp(produce_filename, "-") == 0) {
 		/* Write to the standard output. */
-		example->dump = wtap_dump_open_stdout(WTAP_FILE_TYPE_SUBTYPE_PCAP,
+		example->dump = wtap_dump_open_stdout(file_type_subtype,
 			WTAP_UNCOMPRESSED, &params, &err, &err_info);
 		example->filename = "the standard output";
 	} else {
-		example->dump = wtap_dump_open(produce_filename, WTAP_FILE_TYPE_SUBTYPE_PCAP,
+		example->dump = wtap_dump_open(produce_filename, file_type_subtype,
 			WTAP_UNCOMPRESSED, &params, &err, &err_info);
 		example->filename = produce_filename;
 	}
 	if (!example->dump) {
-		cfile_dump_open_failure_message("randpkt", produce_filename,
-			err, err_info, WTAP_FILE_TYPE_SUBTYPE_PCAP);
+		cfile_dump_open_failure_message(produce_filename,
+			err, err_info, file_type_subtype);
 		return WRITE_ERROR;
 	}
 
@@ -717,7 +718,7 @@ int randpkt_parse_type(char *string)
 	}
 
 	/* Complain */
-	g_error("randpkt: Type %s not known.\n", string);
+	ws_error("randpkt: Type %s not known.\n", string);
 	return -1;
 }
 
