@@ -65,16 +65,16 @@
  */
 
 #include <config.h>
+#define WS_LOG_DOMAIN  LOG_DOMAIN_MAIN
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <wsutil/file_util.h>
 #include <cli_main.h>
-#include <ui/cmdarg_err.h>
-#include <ui/exit_codes.h>
+#include <wsutil/cmdarg_err.h>
 #include <ui/text_import.h>
-#include <ui/version_info.h>
+#include <wsutil/version_info.h>
 #include <ui/failure_message.h>
 #include <wsutil/report_message.h>
 #include <wsutil/inet_addr.h>
@@ -85,6 +85,7 @@
 
 #include <glib.h>
 
+#include <ws_exit_codes.h>
 #include <wsutil/str_util.h>
 #include <wsutil/strnatcmp.h>
 #include <wsutil/wslog.h>
@@ -256,8 +257,8 @@ print_usage (FILE *output)
             "                         Automatically prepends a dummy SCTP DATA\n"
             "                         chunk header with payload protocol identifier ppi.\n"
             "                         Example: -S 30,40,34\n"
-            "  -P <dissector>         prepend EXPORTED_PDU header with specifieddissector\n"
-            "                         as the payload PROTO_NAME tag.\n"
+            "  -P <dissector>         prepend EXPORTED_PDU header with specified dissector\n"
+            "                         as the payload DISSECTOR_NAME tag.\n"
             "                         Automatically sets link type to Upper PDU Export.\n"
             "                         EXPORTED_PDU payload defaults to \"data\" otherwise.\n"
             "\n",
@@ -267,8 +268,8 @@ print_usage (FILE *output)
 
     fprintf(output, "\n"
             "Miscellaneous:\n"
-            "  -h                     display this help and exit\n"
-            "  -v                     print version information and exit\n"
+            "  -h, --help             display this help and exit\n"
+            "  -v, --version          print version information and exit\n"
             "  -q                     don't report processed packet counts\n"
             "");
 }
@@ -346,6 +347,13 @@ list_encap_types(void) {
     g_free(encaps);
 }
 
+static void
+cleanup_dump_params(wtap_dump_params *params)
+{
+    wtap_free_idb_info(params->idb_inf);
+    wtap_dump_params_cleanup(params);
+}
+
 /*----------------------------------------------------------------------
  * Parse CLI options
  */
@@ -402,7 +410,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (!ws_strtou8(ws_optarg, NULL, &radix)) {
                 cmdarg_err("Bad argument for '-b': %s", ws_optarg);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             switch (radix) {
             case  2: info->regex.encoding = ENCODING_PLAIN_BIN; break;
@@ -412,7 +420,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             default:
                 cmdarg_err("Bad argument for '-b': %s", ws_optarg);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             break;
         }
@@ -421,7 +429,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (ws_optarg[0] != 'h' && ws_optarg[0] != 'o' && ws_optarg[0] != 'd' && ws_optarg[0] != 'n') {
                 cmdarg_err("Bad argument for '-o': %s", ws_optarg);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             switch (ws_optarg[0]) {
             case 'o': info->hexdump.offset_type = OFFSET_OCT; break;
@@ -436,7 +444,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (sscanf(ws_optarg, "%x", &hdr_ethernet_proto) < 1) {
                 cmdarg_err("Bad argument for '-e': %s", ws_optarg);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             break;
 
@@ -445,7 +453,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (wtap_encap_type < 0) {
                 cmdarg_err("\"%s\" isn't a valid encapsulation type", ws_optarg);
                 list_encap_types();
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             break;
 
@@ -454,7 +462,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if  (file_type_subtype < 0) {
                 cmdarg_err("\"%s\" isn't a valid capture file type", ws_optarg);
                 list_capture_types();
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             break;
 
@@ -464,7 +472,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (!ws_strtou8(ws_optarg, NULL, &ip_proto)) {
                 cmdarg_err("Bad argument for '-i': %s", ws_optarg);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             set_hdr_ip_proto(ip_proto);
             break;
@@ -486,13 +494,13 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
                 cmdarg_err("%s", gerror->message);
                 g_error_free(gerror);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             } else {
                 if (g_regex_get_string_number(regex, "data") == -1) {
                     cmdarg_err("Regex missing capturing group data (use (?<data>(...)) )");
                     g_regex_unref(regex);
                     print_usage(stderr);
-                    return INVALID_OPTION;
+                    return WS_EXIT_INVALID_OPTION;
                 }
             }
             break;
@@ -506,12 +514,12 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || (*p != ',' && *p != '\0')) {
                 cmdarg_err("Bad src port for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             if (*p == '\0') {
                 cmdarg_err("No dest port specified for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             p++;
             ws_optarg = p;
@@ -519,12 +527,12 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || (*p != ',' && *p != '\0')) {
                 cmdarg_err("Bad dest port for '-s'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             if (*p == '\0') {
                 cmdarg_err("No tag specified for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             p++;
             ws_optarg = p;
@@ -532,7 +540,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || *p != '\0') {
                 cmdarg_err("Bad tag for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
 
             set_hdr_ip_proto(132);
@@ -547,12 +555,12 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || (*p != ',' && *p != '\0')) {
                 cmdarg_err("Bad src port for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             if (*p == '\0') {
                 cmdarg_err("No dest port specified for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             p++;
             ws_optarg = p;
@@ -560,12 +568,12 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || (*p != ',' && *p != '\0')) {
                 cmdarg_err("Bad dest port for '-s'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             if (*p == '\0') {
                 cmdarg_err("No ppi specified for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             p++;
             ws_optarg = p;
@@ -573,7 +581,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || *p != '\0') {
                 cmdarg_err("Bad ppi for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
 
             set_hdr_ip_proto(132);
@@ -594,12 +602,12 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || (*p != ',' && *p != '\0')) {
                 cmdarg_err("Bad src port for '-u'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             if (*p == '\0') {
                 cmdarg_err("No dest port specified for '-u'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             p++;
             ws_optarg = p;
@@ -607,7 +615,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || *p != '\0') {
                 cmdarg_err("Bad dest port for '-u'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             set_hdr_ip_proto(17);
             break;
@@ -621,12 +629,12 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || (*p != ',' && *p != '\0')) {
                 cmdarg_err("Bad src port for '-T'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             if (*p == '\0') {
                 cmdarg_err("No dest port specified for '-u'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             p++;
             ws_optarg = p;
@@ -634,7 +642,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (p == ws_optarg || *p != '\0') {
                 cmdarg_err("Bad dest port for '-T'");
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
             set_hdr_ip_proto(6);
             break;
@@ -651,7 +659,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (!p) {
                 cmdarg_err("Bad source param addr for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
 
             *p = '\0';
@@ -671,13 +679,13 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
                 if (!ws_inet_pton6(ws_optarg, &hdr_ipv6_src_addr)) {
                         cmdarg_err("Bad src addr -%c '%s'", c, p);
                         print_usage(stderr);
-                        return INVALID_OPTION;
+                        return WS_EXIT_INVALID_OPTION;
                 }
             } else {
                 if (!ws_inet_pton4(ws_optarg, &hdr_ip_src_addr)) {
                         cmdarg_err("Bad src addr -%c '%s'", c, p);
                         print_usage(stderr);
-                        return INVALID_OPTION;
+                        return WS_EXIT_INVALID_OPTION;
                 }
             }
 
@@ -685,20 +693,20 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (*p == '\0') {
                 cmdarg_err("No dest addr specified for '-%c'", c);
                 print_usage(stderr);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
 
             if (hdr_ipv6 == TRUE) {
                 if (!ws_inet_pton6(p, &hdr_ipv6_dest_addr)) {
                         cmdarg_err("Bad dest addr for -%c '%s'", c, p);
                         print_usage(stderr);
-                        return INVALID_OPTION;
+                        return WS_EXIT_INVALID_OPTION;
                 }
             } else {
                 if (!ws_inet_pton4(p, &hdr_ip_dest_addr)) {
                         cmdarg_err("Bad dest addr for -%c '%s'", c, p);
                         print_usage(stderr);
-                        return INVALID_OPTION;
+                        return WS_EXIT_INVALID_OPTION;
                 }
             }
             break;
@@ -708,31 +716,31 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             switch(ws_optopt) {
             case 'E':
                 list_encap_types();
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
                 break;
             case 'F':
                 list_capture_types();
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
                 break;
             }
             /* FALLTHROUGH */
 
         default:
             print_usage(stderr);
-            return INVALID_OPTION;
+            return WS_EXIT_INVALID_OPTION;
         }
     }
 
     if (ws_optind >= argc || argc-ws_optind < 2) {
         cmdarg_err("Must specify input and output filename");
         print_usage(stderr);
-        return INVALID_OPTION;
+        return WS_EXIT_INVALID_OPTION;
     }
 
     if (max_offset > WTAP_MAX_PACKET_SIZE_STANDARD) {
         cmdarg_err("Maximum packet length cannot be more than %d bytes",
                 WTAP_MAX_PACKET_SIZE_STANDARD);
-        return INVALID_OPTION;
+        return WS_EXIT_INVALID_OPTION;
     }
 
     /* Some validation */
@@ -747,7 +755,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
         }
         if (g_regex_get_string_number(regex, "time") > -1 && info->timestamp_format == NULL) {
             cmdarg_err("Regex with <time> capturing group requires time format (-t)");
-            return INVALID_OPTION;
+            return WS_EXIT_INVALID_OPTION;
         }
     }
 
@@ -762,7 +770,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
     if (!have_hdr_ip_proto && (hdr_ip || hdr_ipv6)) {
         /* if -4 or -6 option is specified without an IP protocol then fail */
         cmdarg_err("IP protocol requires a next layer protocol number");
-        return INVALID_OPTION;
+        return WS_EXIT_INVALID_OPTION;
     }
 
     if ((hdr_tcp || hdr_udp || hdr_sctp) && !(hdr_ip || hdr_ipv6)) {
@@ -775,7 +783,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
 
     if (hdr_export_pdu && wtap_encap_type != WTAP_ENCAP_WIRESHARK_UPPER_PDU) {
         cmdarg_err("Export PDU (-P) requires WIRESHARK_UPPER_PDU link type (252)");
-        return INVALID_OPTION;
+        return WS_EXIT_INVALID_OPTION;
     }
 
     /* The other dummy headers require a IPv4 or IPv6 header. Allow
@@ -796,7 +804,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
 
         default:
             cmdarg_err("Dummy IPv4 header not supported with encapsulation %s (%s)", wtap_encap_description(wtap_encap_type), wtap_encap_name(wtap_encap_type));
-            return INVALID_OPTION;
+            return WS_EXIT_INVALID_OPTION;
         }
     } else if (hdr_ipv6) {
         switch (wtap_encap_type) {
@@ -812,7 +820,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
 
         default:
             cmdarg_err("Dummy IPv6 header not supported with encapsulation %s (%s)", wtap_encap_description(wtap_encap_type), wtap_encap_name(wtap_encap_type));
-            return INVALID_OPTION;
+            return WS_EXIT_INVALID_OPTION;
         }
     }
 
@@ -823,13 +831,13 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
             if (gerror) {
                 cmdarg_err("%s", gerror->message);
                 g_error_free(gerror);
-                return OPEN_ERROR;
+                return WS_EXIT_OPEN_ERROR;
             }
         } else {
             input_file = ws_fopen(input_filename, "rb");
             if (!input_file) {
                 open_failure_message(input_filename, errno, FALSE);
-                return OPEN_ERROR;
+                return WS_EXIT_OPEN_ERROR;
             }
         }
     } else {
@@ -845,15 +853,13 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
                 cmdarg_err("%s", gerror->message);
                 cmdarg_err("regex import requires memory-mapped I/O and cannot be used with terminals or pipes");
                 g_error_free(gerror);
-                return INVALID_OPTION;
+                return WS_EXIT_INVALID_OPTION;
             }
         }
         input_filename = "Standard input";
         input_file = stdin;
     }
 
-    wtap_dump_params_init(params, NULL);
-
     params->encap = wtap_encap_type;
     params->snaplen = max_offset;
     if (file_type_subtype == WTAP_FILE_TYPE_SUBTYPE_UNKNOWN) {
@@ -865,8 +871,7 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
      */
     params->tsprec = WTAP_TSPREC_NSEC;
     if ((ret = text_import_pre_open(params, file_type_subtype, input_filename, interface_name)) != EXIT_SUCCESS) {
-        g_free(params->idb_inf);
-        wtap_dump_params_cleanup(params);
+        cleanup_dump_params(params);
         return ret;
     }
 
@@ -883,9 +888,8 @@ parse_options(int argc, char *argv[], text_import_info_t * const info, wtap_dump
     if (!wdh) {
         cfile_dump_open_failure_message(output_filename, err, err_info,
                                         file_type_subtype);
-        g_free(params->idb_inf);
-        wtap_dump_params_cleanup(params);
-        return OPEN_ERROR;
+        cleanup_dump_params(params);
+        return WS_EXIT_OPEN_ERROR;
     }
 
     info->import_text_filename = input_filename;
@@ -1008,7 +1012,9 @@ main(int argc, char *argv[])
     ws_log_init("text2pcap", vcmdarg_err);
 
     /* Early logging command-line initialization. */
-    ws_log_parse_args(&argc, argv, vcmdarg_err, INVALID_OPTION);
+    ws_log_parse_args(&argc, argv, vcmdarg_err, WS_EXIT_INVALID_OPTION);
+
+    ws_noisy("Finished log init and parsing command line log arguments");
 
 #ifdef _WIN32
     create_app_running_mutex();
@@ -1019,6 +1025,7 @@ main(int argc, char *argv[])
     wtap_init(TRUE);
 
     memset(&info, 0, sizeof(info));
+    wtap_dump_params_init(&params, NULL);
     if ((ret = parse_options(argc, argv, &info, &params)) != EXIT_SUCCESS) {
         goto clean_exit;
     }
@@ -1054,8 +1061,8 @@ clean_exit:
             cfile_close_failure_message(output_filename, err, err_info);
             ret = 2;
         }
-        g_free(params.idb_inf);
     }
+    cleanup_dump_params(&params);
     return ret;
 }
 
