@@ -16,7 +16,7 @@
 #include <ui/qt/manager/preference_manager.h>
 #include <ui/qt/widgets/range_syntax_lineedit.h>
 #include "ui/qt/widgets/wireshark_file_dialog.h"
-#include <ui/qt/wireshark_application.h>
+#include <ui/qt/main_application.h>
 #include <ui/qt/uat_dialog.h>
 
 #include <QDir>
@@ -51,7 +51,7 @@ public:
     BoolPreference(QObject * parent = Q_NULLPTR) : WiresharkPreference(parent) {}
     virtual QWidget * editor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index)
     {
-        ((QAbstractItemModel*)index.model())->setData(index, QString("BOOL"), Qt::EditRole);
+        const_cast<QAbstractItemModel*>(index.model())->setData(index, QString("BOOL"), Qt::EditRole);
         return WiresharkPreference::editor(parent, option, index);
     }
 };
@@ -81,6 +81,20 @@ public:
 REGISTER_PREFERENCE_TYPE(PREF_STRING, StringPreference)
 REGISTER_PREFERENCE_TYPE(PREF_CUSTOM, StringPreference)
 
+class PasswordPreference : public StringPreference
+{
+public:
+    PasswordPreference(QObject * parent = Q_NULLPTR) : StringPreference(parent) {}
+    virtual QWidget * editor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index)
+    {
+        QLineEdit *le = static_cast<QLineEdit *>(StringPreference::editor(parent, option, index));
+
+        le->setEchoMode(QLineEdit::PasswordEchoOnEdit);
+        return le;
+    }
+};
+REGISTER_PREFERENCE_TYPE(PREF_PASSWORD, PasswordPreference)
+
 class UIntPreference : public StringPreference
 {
 public:
@@ -146,20 +160,27 @@ class ColorPreference : public WiresharkPreference
 {
 public:
     ColorPreference(QObject * parent = Q_NULLPTR) : WiresharkPreference(parent) {}
-    virtual QWidget * editor(QWidget * parent, const QStyleOptionViewItem &option, const QModelIndex &index)
+    virtual QWidget * editor(QWidget * parent, const QStyleOptionViewItem &/*option*/, const QModelIndex &/*index*/)
     {
-        QColorDialog color_dlg;
-        color_t color = *prefs_get_color_value(prefsItem()->getPref(), pref_stashed);
+        QColorDialog* color_dlg = new QColorDialog(parent);
+        color_dlg->setWindowModality(Qt::ApplicationModal);
+        color_dlg->show();
+        return color_dlg;
+    }
 
-        color_dlg.setCurrentColor(QColor(
-                                      color.red >> 8,
-                                      color.green >> 8,
-                                      color.blue >> 8
-                                      ));
-        if (color_dlg.exec() == QDialog::Accepted)
-            ((QAbstractItemModel*)index.model())->setData(index, color_dlg.currentColor().name(), Qt::EditRole);
+    virtual void setData(QWidget *editor, const QModelIndex &index)
+    {
+        QColorDialog* color_dlg = static_cast<QColorDialog*>(editor);
+        QColor color = QColor("#" + index.model()->data(index, Qt::DisplayRole).toString());
+        color_dlg->setCurrentColor(color);
+    }
 
-        return WiresharkPreference::editor(parent, option, index);
+    virtual void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index)
+    {
+        QColorDialog* color_dlg = static_cast<QColorDialog*>(editor);
+        if (color_dlg->result() == QDialog::Accepted) {
+            model->setData(index, color_dlg->currentColor().name(), Qt::EditRole);
+        }
     }
 };
 REGISTER_PREFERENCE_TYPE(PREF_COLOR, ColorPreference)
@@ -170,10 +191,10 @@ public:
     SaveFilePreference(QObject * parent = Q_NULLPTR) : WiresharkPreference(parent) {}
     virtual QWidget * editor(QWidget * parent, const QStyleOptionViewItem &option, const QModelIndex &index)
     {
-        QString filename = WiresharkFileDialog::getSaveFileName(parent, wsApp->windowTitleString(prefs_get_title(prefsItem()->getPref())),
+        QString filename = WiresharkFileDialog::getSaveFileName(parent, mainApp->windowTitleString(prefs_get_title(prefsItem()->getPref())),
                                                     index.model()->data(index, Qt::DisplayRole).toString());
         if (!filename.isEmpty()) {
-            ((QAbstractItemModel*)index.model())->setData(index, QDir::toNativeSeparators(filename), Qt::EditRole);
+            const_cast<QAbstractItemModel*>(index.model())->setData(index, QDir::toNativeSeparators(filename), Qt::EditRole);
         }
         return WiresharkPreference::editor(parent, option, index);
     }
@@ -186,10 +207,10 @@ public:
     OpenFilePreference(QObject * parent = Q_NULLPTR) : WiresharkPreference(parent) {}
     virtual QWidget * editor(QWidget * parent, const QStyleOptionViewItem &option, const QModelIndex &index)
     {
-        QString filename = WiresharkFileDialog::getOpenFileName(parent, wsApp->windowTitleString(prefs_get_title(prefsItem()->getPref())),
+        QString filename = WiresharkFileDialog::getOpenFileName(parent, mainApp->windowTitleString(prefs_get_title(prefsItem()->getPref())),
                                                         index.model()->data(index, Qt::DisplayRole).toString());
         if (!filename.isEmpty()) {
-            ((QAbstractItemModel*)index.model())->setData(index, QDir::toNativeSeparators(filename), Qt::EditRole);
+            const_cast<QAbstractItemModel*>(index.model())->setData(index, QDir::toNativeSeparators(filename), Qt::EditRole);
         }
         return WiresharkPreference::editor(parent, option, index);
     }
@@ -202,10 +223,10 @@ public:
     DirNamePreference(QObject * parent = Q_NULLPTR) : WiresharkPreference(parent) {}
     virtual QWidget * editor(QWidget * parent, const QStyleOptionViewItem &option, const QModelIndex &index)
     {
-        QString filename = WiresharkFileDialog::getExistingDirectory(parent, wsApp->windowTitleString(prefs_get_title(prefsItem()->getPref())),
+        QString filename = WiresharkFileDialog::getExistingDirectory(parent, mainApp->windowTitleString(prefs_get_title(prefsItem()->getPref())),
                                                     index.model()->data(index, Qt::DisplayRole).toString());
         if (!filename.isEmpty()) {
-            ((QAbstractItemModel*)index.model())->setData(index, QDir::toNativeSeparators(filename), Qt::EditRole);
+            const_cast<QAbstractItemModel*>(index.model())->setData(index, QDir::toNativeSeparators(filename), Qt::EditRole);
         }
         return WiresharkPreference::editor(parent, option, index);
     }
@@ -218,25 +239,10 @@ public:
     UatPreference(QObject * parent = Q_NULLPTR) : WiresharkPreference(parent) {}
     virtual QWidget * editor(QWidget * parent, const QStyleOptionViewItem &option, const QModelIndex &index)
     {
-        if (prefsItem()->getPrefGUIType() == GUI_ALL || prefsItem()->getPrefGUIType() == GUI_QT) {
-            UatDialog uat_dlg(parent, prefs_get_uat_value(prefsItem()->getPref()));
-            uat_dlg.exec();
-        }
+        UatDialog uat_dlg(parent, prefs_get_uat_value(prefsItem()->getPref()));
+        uat_dlg.exec();
+
         return WiresharkPreference::editor(parent, option, index);
     }
 };
 REGISTER_PREFERENCE_TYPE(PREF_UAT, UatPreference)
-
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
