@@ -4,11 +4,12 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0-or-later*/
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include <ui/qt/widgets/follow_stream_text.h>
 
-#include <wireshark_application.h>
+#include <main_application.h>
 
 #include <QMouseEvent>
 #include <QTextCursor>
@@ -24,13 +25,18 @@ FollowStreamText::FollowStreamText(QWidget *parent) :
     setMouseTracking(true);
 //    setMaximumBlockCount(1);
     QTextDocument *text_doc = document();
-    text_doc->setDefaultFont(wsApp->monospaceFont());
+    text_doc->setDefaultFont(mainApp->monospaceFont());
 }
 
 void FollowStreamText::mouseMoveEvent(QMouseEvent *event)
 {
     emit mouseMovedToTextCursorPosition(cursorForPosition(event->pos()).position());
-    QPlainTextEdit::mouseMoveEvent(event);
+    // Don't send the mouseMoveEvents with no buttons pushed to the base
+    // class, effectively turning off mouse tracking for the base class.
+    // It causes a lot of useless calculations that hurt scroll performance.
+    if (event->buttons() != Qt::NoButton) {
+        QPlainTextEdit::mouseMoveEvent(event);
+    }
 }
 
 void FollowStreamText::mousePressEvent(QMouseEvent *event)
@@ -44,16 +50,3 @@ void FollowStreamText::leaveEvent(QEvent *event)
     emit mouseMovedToTextCursorPosition(-1);
     QPlainTextEdit::leaveEvent(event);
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
