@@ -1,28 +1,30 @@
-/* tap-rlc-stream.h
+/** @file
+ *
  * LTE RLC stream statistics
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0+*/
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef __TAP_RLC_GRAPH_H__
 #define __TAP_RLC_GRAPH_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include <epan/epan.h>
 #include <epan/packet.h>
 #include <cfile.h>
 #include <epan/dissectors/packet-rlc-lte.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 struct rlc_segment {
     struct rlc_segment *next;
     guint32         num;            /* framenum */
-    guint32         rel_secs;
+    time_t          rel_secs;
     guint32         rel_usecs;
 
     gboolean        isControlPDU;
@@ -61,9 +63,6 @@ struct rlc_graph {
     guint16         channelId;
     guint8          rlcMode;
     guint8          direction;
-
-    /* Lists of elements to draw. N.B. GTK version only. */
-    struct element_list *elists;
 };
 
 gboolean rlc_graph_segment_list_get(capture_file *cf, struct rlc_graph *tg, gboolean stream_known,
